Class: Minitest::Test
- Inherits:
-
Object
- Object
- Minitest::Test
- Defined in:
- lib/minitest/rematch_plugin.rb
Overview
Reopen the minitest class
Instance Method Summary collapse
-
#after_setup ⇒ Object
Create the rematch object for each test.
-
#before_teardown ⇒ Object
Ensure store is tidied and saved after the test runs.
Instance Method Details
#after_setup ⇒ Object
Create the rematch object for each test
23 24 25 26 |
# File 'lib/minitest/rematch_plugin.rb', line 23 def after_setup super @rematch = Rematch.new(self) end |
#before_teardown ⇒ Object
Ensure store is tidied and saved after the test runs
29 30 31 32 |
# File 'lib/minitest/rematch_plugin.rb', line 29 def before_teardown super @rematch&.save end |